@@ -1,47 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from collections import Counter, defaultdict, namedtuple
-from typing import Union, List, Dict, Any
+from collections import defaultdict, namedtuple
 
 from loguru import logger
-from rich.live import Live
-from rich.text import Text
 
-from .. import T, __respath__
-from .plugin import event_bus
-from ..llm import CLIENTS, ChatMessage, ModelRegistry, ModelCapability
+from .. import T, __respath__, __version__
+from ..llm import CLIENTS, ModelRegistry, ModelCapability
 from .multimodal import LLMContext
 
-class ChatHistory:
-    def __init__(self):
-        self.messages = []
-        self._total_tokens = Counter()
-
-    def __len__(self):
-        return len(self.messages)
-    
-    def json(self):
-        return [msg.__dict__ for msg in self.messages]
-    
-    def add(self, role, content):
-        self.add_message(ChatMessage(role=role, content=content))
-
-    def add_message(self, message: ChatMessage):
-        self.messages.append(message)
-        self._total_tokens += message.usage
-
-    def get_usage(self):
-        return iter(row.usage for row in self.messages if row.role == "assistant")
-    
-    def get_summary(self):
-        summary = {'time': 0, 'input_tokens': 0, 'output_tokens': 0, 'total_tokens': 0}
-        summary.update(dict(self._total_tokens))
-        summary['rounds'] = sum(1 for row in self.messages if row.role == "assistant")
-        return summary
-
-    def get_messages(self):
-        return [{"role": msg.role, "content": msg.content} for msg in self.messages]
-
 class LineReceiver(list):
     def __init__(self):
         super().__init__()
@@ -57,8 +23,9 @@ class LineReceiver(list):
 
         while '\n' in self.buffer:
             line, self.buffer = self.buffer.split('\n', 1)
-            self.append(line)
-            new_lines.append(line)
+            if line:
+                self.append(line)
+                new_lines.append(line)
 
         return new_lines
     
@@ -72,17 +39,14 @@ class LineReceiver(list):
             self.buffer = ""
         return buffer
 
-class LiveManager:
-    def __init__(self, name, quiet=False):
-        self.live = None
+class StreamProcessor:
+    """流式数据处理器，负责处理 LLM 流式响应并发送事件"""
+    
+    def __init__(self, task, name):
+        self.task = task
         self.name = name
         self.lr = LineReceiver()
         self.lr_reason = LineReceiver()
-        self.title = f"{self.name} {T('Reply')}"
-        self.reason_started = False
-        self.display_lines = []
-        self.max_lines = 10
-        self.quiet = quiet
 
     @property
     def content(self):
@@ -93,47 +57,38 @@ class LiveManager:
         return self.lr_reason.content
     
     def __enter__(self):
-        if self.quiet: return self
-        self.live = Live(auto_refresh=False, vertical_overflow='crop', transient=True)
-        self.live.__enter__()
+        """支持上下文管理器协议"""
+        self.task.emit('stream_start', llm=self.name)
         return self
-
+    
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        """支持上下文管理器协议"""
+        if self.lr.buffer:
+            self.process_chunk('\n')        
+        self.task.emit('stream_end', llm=self.name)
+    
     def process_chunk(self, content, *, reason=False):
-        if not content: return
- 
+        """处理流式数据块并发送事件"""
+        if not content: 
+            return
+
+        # 处理思考内容的结束
         if not reason and self.lr.empty() and not self.lr_reason.empty():
             line = self.lr_reason.done()
-            event_bus.broadcast('response_stream', {'llm': self.name, 'content': f"{line}\n\n----\n\n", 'reason': True})
+            if line:
+                self.task.emit('stream', llm=self.name, lines=[line, "\n\n----\n\n"], reason=True)
 
+        # 处理当前数据块
         lr = self.lr_reason if reason else self.lr
         lines = lr.feed(content)
-        if not lines: return
-
+        if not lines:
+            return
+        
+        # 过滤掉特殊注释行
         lines2 = [line for line in lines if not line.startswith('<!-- Block-') and not line.startswith('<!-- Cmd-')]
         if lines2:
-            content = '\n'.join(lines2)
-            event_bus.broadcast('response_stream', {'llm': self.name, 'content': content, 'reason': reason})
+            self.task.emit('stream', llm=self.name, lines=lines2, reason=reason)
 
-        if self.quiet: return
-
-        if reason and not self.reason_started:
-            self.display_lines.append("<think>")
-            self.reason_started = True
-        elif not reason and self.reason_started:
-            self.display_lines.append("</think>")
-            self.reason_started = False
-
-        self.display_lines.extend(lines)
-        while len(self.display_lines) > self.max_lines:
-            self.display_lines.pop(0)
-        content = '\n'.join(self.display_lines)
-        self.live.update(Text(content, style="dim white"), refresh=True)
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        if self.lr.buffer:
-            self.process_chunk('\n')
-        if self.live:
-            self.live.__exit__(exc_type, exc_val, exc_tb)
 
 class ClientManager(object):
     MAX_TOKENS = 8192
@@ -145,7 +100,7 @@ class ClientManager(object):
         self.log = logger.bind(src='client_manager')
         self.names = self._init_clients(settings)
         self.model_registry = ModelRegistry(__respath__ / "models.yaml")
-
+        
     def _create_client(self, config):
         kind = config.get("type", "openai")
         client_class = CLIENTS.get(kind.lower())
@@ -211,8 +166,8 @@ class ClientManager(object):
     def get_client(self, name):
         return self.clients.get(name)
     
-    def Client(self):
-        return Client(self)
+    def Client(self, task, context_manager):
+        return Client(self, task, context_manager)
     
     def to_records(self):
         LLMRecord = namedtuple('LLMRecord', ['Name', 'Model', 'Max_Tokens', 'Base_URL'])
@@ -225,12 +180,21 @@ class ClientManager(object):
         return self.model_registry.get_model_info(model)
     
 class Client:
-    def __init__(self, manager: ClientManager):
+    def __init__(self, manager: ClientManager, task, context_manager):
         self.manager = manager
         self.current = manager.current
-        self.history = ChatHistory()
+        self.task = task
+        self.extra_headers = {'Aipy-Task-ID': f'{task.task_id}/{__version__}'}
+        
+        # 接收外部传入的上下文管理器
+        self.context_manager = context_manager
+        
         self.log = logger.bind(src='client', name=self.current.name)
 
+    def add_message(self, message):
+        """添加消息"""
+        self.context_manager.add_message(message)
+
     @property
     def name(self):
         return self.current.name
@@ -270,12 +234,11 @@ class Client:
         
         return any(capability in model_info.capabilities for capability in capabilities)
     
-    def __call__(self, content: LLMContext, *, system_prompt=None, quiet=False):
+    def __call__(self, content: LLMContext, *, system_prompt=None):
         client = self.current
-        stream_processor = LiveManager(client.name, quiet=quiet)
-        msg = client(self.history, content, system_prompt=system_prompt, stream_processor=stream_processor)
-        if msg:
-            event_bus.broadcast('response_complete', {'llm': client.name, 'content': msg})
-        else:
-            self.log.error(f"LLM: {client.name} response is None")
+        stream_processor = StreamProcessor(self.task, client.name)
+        
+        # 直接传递 ContextManager，它已经实现了所需的接口
+        msg = client(self.context_manager, content, system_prompt=system_prompt, stream_processor=stream_processor, extra_headers=self.extra_headers)
         return msg
+    
\ No newline at end of file
